Navigator API

# Welcome to Navigator!

This is Navigator, a Framework with "batteries-included", a comprehensive collection of asyncio-based libraries to easily create any python project in minutes.

Navigator is based on python >= 3.8, Asyncio and other fantastic asynchronous technologies like:

- Aiohttp
- Python 3.8
- Asyncio+uvloop
- asyncpg
- SockJS

And many others, a Framework designed with a "functional-first" philosophy, is an async "micro-Django" with many tools for easy deployment and development of async applications.

Navigator has some fantastic features as:

- Applications: like django, you can create "apps" in the "apps/" folder, extending from AppConfig, and Navigator make the rest.
- Sub-Domains: an Application can start its own SubDomain, perfect for isolating applications between tenants.
- Central Config: You can declare your configuration in INI files, secrets in environment files, but everything will be access from one single point of truth.
- Auto-Connections: Based on AsyncDB (a tool for integrating several database connectors), every App can start automatically a connection, accessed by "request" object.
- Authentication Backend with Middlewares: A pluggable Authentication/Authorization Backend with Middleware Support.
- Built-in Notifications: Can send Notifications and messages with several backends (emails, sms, telegram, slack) using background jobs.
- And other features: WebSockets, Jinja Templates, Model Views, etc